@@ -8,12 +8,11 @@
 #define __LIBXMLPP_NODES_PINODE_H
 
 #include <libxml++/nodes/contentnode.h>
-#include <libxml++/api_export.h>
 
 namespace xmlpp
 {
 
-class LIBXMLPP_API ProcessingInstructionNode : public ContentNode
+class ProcessingInstructionNode : public ContentNode
 {
 public:
   explicit ProcessingInstructionNode(_xmlNode* node);
