@@ -8,14 +8,13 @@
 #define __LIBXMLPP_NODES_TEXTNODE_H
 
 #include <libxml++/nodes/contentnode.h>
-#include <libxml++/api_export.h>
 
 namespace xmlpp
 {
 
 /** Text Node. This will be instantiated by the parser.
 */
-class LIBXMLPP_API TextNode : public ContentNode
+class TextNode : public ContentNode
 {
 public:
   explicit TextNode(_xmlNode* node);
